@@ -39,16 +39,16 @@ gpe_get_win_position (Display *dpy, Window win, int *x, int *y)
       int w_x, w_y ;
       unsigned int border_w ;
       if (children) 
-	XFree (children);
+        XFree (children);
 
       if (!XGetGeometry( dpy, win, &root, &w_x, &w_y, &udumm, &udumm, &border_w, &udumm ))
-	break ;
+        break ;
 
       (*x)+=w_x+(int)border_w ;
       (*y)+=w_y+(int)border_w ;
       
       if (parent == root)
-	return 1;
+        return 1;
 
       win = parent ;
     }
@@ -66,7 +66,9 @@ gpe_popup_menu_position (GtkMenu *menu, gint *xp, gint *yp, gboolean *push, gpoi
   
   gpe_get_win_position (GDK_WINDOW_XDISPLAY (w->window), GDK_WINDOW_XWINDOW (w->window), &x, &y);
 
-  *xp = x + w->allocation.x;
+  *xp = x;
+  if (GTK_WIDGET_NO_WINDOW (w))
+    x += w->allocation.x;
   *yp = y - GTK_WIDGET (menu)->requisition.height;
 
   if (*yp < 0)
